@@ -104,7 +104,7 @@ async def callback(message: aio_pika.IncomingMessage):
                 print("Unknown command: {}".format(command))
                 sys.stdout.flush()
         except Exception as e:
-            print("Failed overall message processing: " + str(e))
+            print("Failed overall message processing: " +  str(sys.exc_info()[-1].tb_lineno) + " " +str(e))
             sys.stdout.flush()
 
 async def get_status(request):
@@ -321,7 +321,7 @@ async def rabbit_c2_rpc_callback(
             )
         except Exception as e:
             print_flush(
-                "Exception trying to send message back to container for rpc! " + str(e)
+                "Exception trying to send message back to container for rpc! " + str(sys.exc_info()[-1].tb_lineno) + " " + str(e)
             )
 
 
@@ -358,7 +358,7 @@ async def connect_and_consume_rpc(debug):
             partial(rabbit_c2_rpc_callback, channel.default_exchange)
         )
     except Exception as e:
-        print_flush("Exception in connect_and_consume_rpc .consume: {}".format(str(e)))
+        print_flush("Exception in connect_and_consume_rpc .consume: {}".format(str(sys.exc_info()[-1].tb_lineno) + " " + str(e)))
 
 
 async def rabbit_mythic_c2_rpc_callback(
@@ -379,7 +379,7 @@ async def rabbit_mythic_c2_rpc_callback(
             )
         except Exception as e:
             print(
-                "[-] Exception trying to send message back to container for rpc! " + str(e)
+                "[-] Exception trying to send message back to container for rpc! " + str(sys.exc_info()[-1].tb_lineno) + " " + str(e)
             )
             sys.stdout.flush()
 
@@ -418,9 +418,8 @@ async def connect_and_consume_mythic_rpc(debug):
         )
         # wait to sync classes with mythic until we have a way to get messages back
         await sync_classes()
-        result = await asyncio.wait_for(task, None)
     except Exception as e:
-        print_flush("Exception in connect_and_consume_mythic_rpc .consume: {}".format(str(e)))
+        print_flush("Exception in connect_and_consume_mythic_rpc .consume: {}".format(str(sys.exc_info()[-1].tb_lineno) + " " + str(e)))
 
 
 async def mythic_service(debug: bool):
@@ -526,7 +525,7 @@ async def heartbeat_loop(debug: bool):
                 )
                 await asyncio.sleep(10)
             except Exception as e:
-                print_flush("Exception in heartbeat_loop trying to send heartbeat: " + str(e))
+                print_flush("Exception in heartbeat_loop trying to send heartbeat: " + str(sys.exc_info()[-1].tb_lineno) + " " + str(e))
                 # if we get an exception here, break out to the bigger loop and try to connect again
                 break
 
